@@ -46,6 +46,6 @@ def run():
     from Corellia.worker import WorkerPool
     import Husky
     from ..config import config
-    Worker(config.host, "Briareus", pickler=Husky, serialize=True).run(Runtime)
+    Worker(config.host, "Briareus", pickler=Husky, serialize=False).run(Runtime)
 
 
